#!/usr/bin/env python
# -*- coding: utf-8 -*-
########################################################################
#
# mamehist.py
# A simple reader utility for the MAME history.dat
#
# Copyright (c) 2009 Elias Schwerdtfeger, http://www.tamagothi.de/
#
# Licensed under the terms of the pirate's license. You can do with
# this program whatever you like, as long as you do not sue me. If
# you want to sue me, ask me for a commercial license.
#
# Of course no warranty. This program may eat your hard drive, trash
# your data and traumatize your cat. It's your risk. 
#
########################################################################


import sys
import os
import re
import locale
from codecs import EncodedFile
from formatter import AbstractFormatter, DumbWriter
from subprocess import Popen, PIPE


locale.setlocale(locale.LC_ALL, '')


PAGER = os.getenv('PAGER', 'less')
DATFILE = os.getenv('HISTORYDAT', '/usr/share/games/xmame/history.dat')
LOCALENC = locale.getpreferredencoding()


if len(sys.argv) < 2:
    exit('Usage: %s romname' % (sys.argv[0],))
elif len(sys.argv) > 2:
    exit('Too many arguments')
else:
    term = sys.argv[1]


inf_re = re.compile(r'\$info\=([0-9a-z]*)', re.I)
bio_re = re.compile(r'\$bio', re.I)
end_re = re.compile(r'\$end', re.I)




state = 0
hfh = open(DATFILE, 'rU')
pro = None
of = None
af = None


for line in hfh:
    if state == 0:
        m = inf_re.match(line)
        if m:
            found = m.group(1)
            games = found.split(',')
            if term in games:
                state = 1
    elif state == 1:
        if bio_re.match(line):
            state = 2
            pro = Popen(PAGER, stdin=PIPE, shell=True)
            of = EncodedFile(pro.stdin, 'iso-8859-1', LOCALENC)
            af = AbstractFormatter(DumbWriter(of))
    elif state == 2:
        if end_re.match(line):
            break
        line = line.strip()
        if len(line) == 0:
            af.end_paragraph(1)
        else:
            af.add_flowing_data(line)


if pro:
    of.close()
    pro.wait()
else:
    sys.exit('No %s in the history.dat\n' % (term,))
    
